@@ -464,7 +464,7 @@ static int readOHDRHeaderMessageDataLayout(struct READER *reader,
                                            struct DATAOBJECT *data) {
 
   int i, err;
-  unsigned size;
+  uint64_t size;
 
   uint8_t dimensionality, layout_class;
   uint32_t dataset_element_size;
@@ -546,7 +546,7 @@ static int readOHDRHeaderMessageDataLayout(struct READER *reader,
       if (mysofa_seek(reader, data_address, SEEK_SET) < 0)
         return errno; // LCOV_EXCL_LINE
       if (!data->data) {
-        if (size > 0x10000000)
+        if (size > 0x100000000)
           return MYSOFA_INVALID_FORMAT; // LCOV_EXCL_LINE
         data->data_len = size;
         data->data = calloc(1, size);
@@ -622,7 +622,7 @@ static int readOHDRHeaderMessageGroupInfo(struct READER *reader,
 static int readOHDRHeaderMessageFilterPipelineV1(struct READER *reader,
                                                  uint8_t filters) {
   int i, j;
-  uint16_t filter_identification_value, number_client_data_values,
+  uint16_t filter_identification_value, flags, number_client_data_values,
       namelength;
 
   if (readValue(reader, 6) != 0) {
@@ -645,7 +645,7 @@ static int readOHDRHeaderMessageFilterPipelineV1(struct READER *reader,
       // LCOV_EXCL_STOP
     }
     namelength = (uint16_t)readValue(reader, 2);
-    readValue(reader, 2);
+    flags = (uint16_t)readValue(reader, 2);
     number_client_data_values = (uint16_t)readValue(reader, 2);
 
     if (namelength > 0)
