@@ -21,10 +21,10 @@ MYSOFA_EXPORT int mysofa_resample(struct MYSOFA_HRTF *hrtf, float samplerate) {
   unsigned newN;
   float *values;
   SpeexResamplerState *resampler;
-  float *out;
   float zero[10] = {0, 0, 0, 0, 0, 0, 0, 0, 0, 0};
 
-  if (hrtf->DataSamplingRate.elements != 1 || samplerate < 8000.)
+  if (hrtf->DataSamplingRate.elements != 1 || samplerate < 8000. ||
+      hrtf->DataIR.elements != hrtf->R * hrtf->M * hrtf->N)
     return MYSOFA_INVALID_FORMAT;
 
   if (samplerate == hrtf->DataSamplingRate.values[0])
@@ -36,6 +36,7 @@ MYSOFA_EXPORT int mysofa_resample(struct MYSOFA_HRTF *hrtf, float samplerate) {
   /*
    * resample FIR filter
    */
+
   values = malloc(newN * hrtf->R * hrtf->M * sizeof(float));
   if (values == NULL)
     return MYSOFA_NO_MEMORY;
@@ -47,26 +48,26 @@ MYSOFA_EXPORT int mysofa_resample(struct MYSOFA_HRTF *hrtf, float samplerate) {
     return err;
   }
 
-  out = malloc(sizeof(float) *
-               (newN + speex_resampler_get_output_latency(resampler)));
-  for (i = 0; i < hrtf->R * hrtf->M; i++) {
-    unsigned inlen = hrtf->N;
-    unsigned outlen = newN;
-    speex_resampler_reset_mem(resampler);
-    speex_resampler_skip_zeros(resampler);
-    speex_resampler_process_float(resampler, 0,
-                                  hrtf->DataIR.values + i * hrtf->N, &inlen,
-                                  values + i * newN, &outlen);
-    assert(inlen == hrtf->N);
-    while (outlen < newN) {
-      unsigned difflen = newN - outlen;
-      inlen = 10;
-      speex_resampler_process_float(resampler, 0, zero, &inlen,
-                                    values + i * newN + outlen, &difflen);
-      outlen += difflen;
+  if (hrtf->N) {
+    for (i = 0; i < hrtf->R * hrtf->M; i++) {
+      unsigned inlen = hrtf->N;
+      unsigned outlen = newN;
+      speex_resampler_reset_mem(resampler);
+      speex_resampler_skip_zeros(resampler);
+      speex_resampler_process_float(resampler, 0,
+                                    hrtf->DataIR.values + i * hrtf->N, &inlen,
+                                    values + i * newN, &outlen);
+      assert(inlen == hrtf->N);
+      while (outlen < newN) {
+        unsigned difflen = newN - outlen;
+        inlen = 10;
+        speex_resampler_process_float(resampler, 0, zero, &inlen,
+                                      values + i * newN + outlen, &difflen);
+        outlen += difflen;
+      }
+      assert(outlen == newN);
     }
   }
-  free(out);
   speex_resampler_destroy(resampler);
 
   free(hrtf->DataIR.values);
