@@ -4,7 +4,9 @@
  *  Created on: 13.01.2017
  *      Author: hoene
  */
+#ifndef _USE_MATH_DEFINES
 #define _USE_MATH_DEFINES
+#endif // !_USE_MATH_DEFINES
 #include "tools.h"
 #include "mysofa.h"
 #include "mysofa_export.h"
@@ -23,7 +25,8 @@ char *mysofa_strdup(const char *str) {
 
 int verifyAttribute(struct MYSOFA_ATTRIBUTE *attr, char *name, char *value) {
   while (attr) {
-    if (!strcmp(name, attr->name) && !strcmp(value, attr->value))
+    if (attr->name && !strcmp(name, attr->name) && attr->value &&
+        !strcmp(value, attr->value))
       return 1;
     attr = attr->next;
   }
@@ -34,7 +37,7 @@ int changeAttribute(struct MYSOFA_ATTRIBUTE *attr, char *name, char *value,
                     char *newvalue) {
   while (attr) {
     if (!strcmp(name, attr->name) &&
-        (value == NULL || !strcmp(value, attr->value))) {
+        (value == NULL || attr->value == NULL || !strcmp(value, attr->value))) {
       free(attr->value);
       attr->value = mysofa_strdup(newvalue);
       return 1;
@@ -47,7 +50,7 @@ int changeAttribute(struct MYSOFA_ATTRIBUTE *attr, char *name, char *value,
 MYSOFA_EXPORT
 char *mysofa_getAttribute(struct MYSOFA_ATTRIBUTE *attr, char *name) {
   while (attr) {
-    if (!strcmp(name, attr->name)) {
+    if (attr->name && !strcmp(name, attr->name)) {
       return attr->value;
     }
     attr = attr->next;
